---
title: 'antivirus:signatureproviders'
url: 'https://docs.danami.com/warden/command-line-interface/antivirus/antivirus-signatureproviders'
markdown: 'https://docs.danami.com/warden/command-line-interface/antivirus/antivirus-signatureproviders.md'
date: '2026-10-07'
description: 'Configure third party ClamAV antivirus signature providers. warden --task=antivirus:signatureproviders Option Value Default Description --sanesecurity_enable <1|0> 0 Enable or disable the SaneSecurity signature provider. --sanesecurity_provider_url <string> https://ftp.swin.e…'
taxonomy:
  category:
    - docs
  tag:
    - antivirus
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Antivirus       antivirus:signatureproviders    

# antivirus:signatureproviders

Configure third party ClamAV antivirus signature providers.

```
warden --task=antivirus:signatureproviders
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--sanesecurity_enable` | <1\|0> | 0 | Enable or disable the SaneSecurity signature provider. |
| `--sanesecurity_provider_url` | <string> | https://ftp.swin.edu.au/sanesecurity/ | The base URL of this signature provider. |
| `--sanesecurity_provider_files` | <string1,string2> | badmacro.ndb blurl.ndb bofhland\_cracked\_URL.ndb bofhland\_malware\_attach.hdb bofhland\_malware\_URL.ndb bofhland\_phishing\_URL.ndb foxhole\_filename.cdb foxhole\_generic.cdb foxhole\_js.cdb foxhole\_js.ndb hackingteam.hsb junk.ndb jurlbl.ndb jurlbla.ndb lott.ndb malwarehash.hsb phish.ndb phishtank.ndb porcupine.ndb rogue.hdb scam.ndb shelter.ldb spamattach.hdb spamimg.hdb spear.ndb spearl.ndb winnow.attachments.hdb winnow\_bad\_cw.hdb winnow\_extended\_malware.hdb winnow\_extended\_malware\_links.ndb winnow\_malware.hdb winnow\_malware\_links.ndb winnow\_phish\_complete\_url.ndb winnow\_spam\_complete.ndb | The signature database files to download from this provider. |
| `--securiteinfo_enable` | <1\|0> | 0 | Enable or disable the SecuriteInfo signature provider. |
| `--securiteinfo_provider_url` | <string> | https://www.securiteinfo.com/get/signatures/YOUR\_API\_KEY/ | The base URL of this signature provider. |
| `--securiteinfo_provider_files` | <string1,string2> | securiteinfoandroid.hdb securiteinfoascii.hdb securiteinfohtml.hdb javascript.ndb securiteinfopdf.hdb securiteinfo.hdb securiteinfo.ign2 securiteinfo-pua-app-and-vulnerabilities.ndb | The signature database files to download from this provider. |
| `--urlhaus_enable` | <1\|0> | 0 | Enable or disable the URLhaus signature provider. |
| `--urlhaus_provider_url` | <string> | https://urlhaus.abuse.ch/downloads/ | The base URL of this signature provider. |
| `--urlhaus_provider_files` | <string1,string2> | urlhaus.ndb | The signature database files to download from this provider. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--restart` | <yes> |  | Restart the service after saving settings. |

## Examples

```
// enable the sanesecurity signatures
warden --task=antivirus:signatureproviders --sanesecurity_enable=1 --restart=yes

// reset the sanesecurity back to its default value
warden --task=antivirus:signatureproviders --default_option=sanesecurity_enable --restart=yes

// reset all settings to their default values
warden --task=antivirus:signatureproviders --default=yes --restart=yes

// enable the URLhaus and SecuriteInfo providers
warden --task=antivirus:signatureproviders --urlhaus_enable=1 --securiteinfo_enable=1 --restart=yes
```

## Related Pages

- [Scanning Settings](https://docs.danami.com/warden/settings/antivirus/scanning-settings "Scanning Settings")
- [Scanning Limits](https://docs.danami.com/warden/settings/antivirus/scanning-limits "Scanning Limits")
- [Anti-virus](https://docs.danami.com/warden/user-guide/antivirus "Anti-virus")
- [Antivirus](https://docs.danami.com/warden/user-guide/antispam-plugins/antivirus "Antivirus")

 [ ](https://docs.danami.com/warden/command-line-interface/antivirus/antivirus-scanninglimits) [](https://docs.danami.com/warden/settings/antivirus/scanning-settings)

---

## Navigation

- Previous: [antivirus:scanninglimits](https://docs.danami.com/warden/command-line-interface/antivirus/antivirus-scanninglimits.md)
- Next: [antivirus:signatureupdates](https://docs.danami.com/warden/command-line-interface/antivirus/antivirus-signatureupdates.md)
